from setuptools import setup

setup(
    name='PythonPip',
    version='1.1',
    packages=['myPackage', 'myPackage.libPackage', 'myPackage.libPackage2'],
    url='https://github.com/helmanso123/PythonLib/',
    license='MIT',
    author='Krzysztof Puciłowski',
    author_email='248405@student.pwr.edu.pl',
    description='first version'
)
